# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-09-29 19:46
from __future__ import unicode_literals

import django.db.models.deletion
import django.db.models.manager
import django.utils.timezone
import repomaker.models.storage
import repomaker.storage
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Apk',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('package_id', models.CharField(blank=True, max_length=255)),
                ('file', models.FileField(storage=repomaker.storage.RepoStorage(), upload_to=repomaker.storage.get_apk_file_path)),
                ('version_name', models.CharField(blank=True, max_length=128)),
                ('version_code', models.PositiveIntegerField(default=0)),
                ('size', models.PositiveIntegerField(default=0)),
                ('signature', models.CharField(blank=True, max_length=512, null=True)),
                ('hash', models.CharField(blank=True, max_length=512)),
                ('hash_type', models.CharField(blank=True, max_length=32)),
                ('added_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('is_downloading', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='ApkPointer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(storage=repomaker.storage.RepoStorage(), upload_to=repomaker.storage.get_apk_file_path)),
                ('apk', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='repomaker.Apk')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='App',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('package_id', models.CharField(blank=True, max_length=255)),
                ('name', models.CharField(blank=True, max_length=255)),
                ('summary_override', models.CharField(blank=True, max_length=255)),
                ('description_override', models.TextField(blank=True)),
                ('author_name', models.CharField(blank=True, max_length=255)),
                ('website', models.URLField(blank=True, max_length=2048)),
                ('icon', models.ImageField(upload_to=repomaker.storage.get_icon_file_path_for_app)),
                ('added_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('type', models.CharField(choices=[('apk', 'APK'), ('book', 'Book'), ('document', 'Document'), ('image', 'Image'), ('audio', 'Audio'), ('video', 'Video'), ('other', 'Other')], default='apk', max_length=16)),
                ('last_updated_date', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
                'ordering': ['added_date'],
            },
            managers=[
                ('objects', django.db.models.manager.Manager()),
                ('_plain_manager', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='AppTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('summary', models.CharField(blank=True, max_length=255)),
                ('description', models.TextField(blank=True)),
                ('feature_graphic', models.ImageField(blank=True, max_length=1024, upload_to=repomaker.storage.get_graphic_asset_file_path)),
                ('high_res_icon', models.ImageField(blank=True, max_length=1024, upload_to=repomaker.storage.get_graphic_asset_file_path)),
                ('tv_banner', models.ImageField(blank=True, max_length=1024, upload_to=repomaker.storage.get_graphic_asset_file_path)),
                ('language_code', models.CharField(db_index=True, max_length=15)),
                ('master', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='repomaker.App')),
            ],
            options={
                'abstract': False,
                'db_table': 'repomaker_app_translation',
                'managed': True,
                'db_tablespace': '',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Categories',
            },
        ),
        migrations.CreateModel(
            name='GitStorage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('host', models.CharField(max_length=256, validators=[repomaker.models.storage.HostnameValidator()])),
                ('path', models.CharField(max_length=512, validators=[repomaker.models.storage.PathValidator()])),
                ('identity_file', models.FileField(blank=True, storage=repomaker.storage.PrivateStorage(), upload_to=repomaker.storage.get_identity_file_path)),
                ('public_key', models.TextField(blank=True, null=True)),
                ('url', models.URLField(max_length=2048)),
                ('disabled', models.BooleanField(default=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RemoteApkPointer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(max_length=2048)),
                ('apk', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='repomaker.Apk')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RemoteApp',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('package_id', models.CharField(blank=True, max_length=255)),
                ('name', models.CharField(blank=True, max_length=255)),
                ('summary_override', models.CharField(blank=True, max_length=255)),
                ('description_override', models.TextField(blank=True)),
                ('author_name', models.CharField(blank=True, max_length=255)),
                ('website', models.URLField(blank=True, max_length=2048)),
                ('icon', models.ImageField(upload_to=repomaker.storage.get_icon_file_path_for_app)),
                ('added_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('icon_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('last_updated_date', models.DateTimeField(blank=True)),
                ('category', models.ManyToManyField(blank=True, to='repomaker.Category')),
            ],
            options={
                'abstract': False,
                'ordering': ['added_date'],
            },
            managers=[
                ('objects', django.db.models.manager.Manager()),
                ('_plain_manager', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='RemoteAppTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('summary', models.CharField(blank=True, max_length=255)),
                ('description', models.TextField(blank=True)),
                ('feature_graphic_url', models.URLField(blank=True, max_length=2048)),
                ('feature_graphic_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('high_res_icon_url', models.URLField(blank=True, max_length=2048)),
                ('high_res_icon_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('tv_banner_url', models.URLField(blank=True, max_length=2048)),
                ('tv_banner_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('language_code', models.CharField(db_index=True, max_length=15)),
                ('master', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='repomaker.RemoteApp')),
            ],
            options={
                'abstract': False,
                'db_table': 'repomaker_remoteapp_translation',
                'managed': True,
                'db_tablespace': '',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='RemoteRepository',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('url', models.URLField(blank=True, max_length=2048, null=True)),
                ('icon', models.ImageField(upload_to=repomaker.storage.get_icon_file_path)),
                ('public_key', models.TextField(blank=True)),
                ('fingerprint', models.CharField(blank=True, max_length=512)),
                ('update_scheduled', models.BooleanField(default=False)),
                ('is_updating', models.BooleanField(default=False)),
                ('last_updated_date', models.DateTimeField(auto_now=True)),
                ('pre_installed', models.BooleanField(default=False)),
                ('index_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('icon_etag', models.CharField(blank=True, max_length=128, null=True)),
                ('mirrors', models.TextField(blank=True)),
                ('disabled', models.BooleanField(default=False)),
                ('last_change_date', models.DateTimeField()),
                ('users', models.ManyToManyField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Remote Repositories',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RemoteScreenshot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(default='en', max_length=32)),
                ('type', models.CharField(choices=[('phoneScreenshots', 'Phone'), ('sevenInchScreenshots', "7'' Tablet"), ('tenInchScreenshots', "10'' Tablet"), ('tvScreenshots', 'TV'), ('wearScreenshots', 'Wearable')], default='phoneScreenshots', max_length=32)),
                ('url', models.URLField(max_length=2048)),
                ('app', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.RemoteApp')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Repository',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('url', models.URLField(blank=True, max_length=2048, null=True)),
                ('icon', models.ImageField(upload_to=repomaker.storage.get_icon_file_path)),
                ('public_key', models.TextField(blank=True)),
                ('fingerprint', models.CharField(blank=True, max_length=512)),
                ('update_scheduled', models.BooleanField(default=False)),
                ('is_updating', models.BooleanField(default=False)),
                ('last_updated_date', models.DateTimeField(auto_now=True)),
                ('qrcode', models.ImageField(blank=True, upload_to=repomaker.storage.get_repo_file_path)),
                ('key_store_pass', models.CharField(max_length=64)),
                ('key_pass', models.CharField(max_length=64)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_publication_date', models.DateTimeField(blank=True, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Repositories',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='S3Storage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('disabled', models.BooleanField(default=False)),
                ('region', models.CharField(choices=[('s3', 'US Standard')], default='s3', max_length=32)),
                ('bucket', models.CharField(max_length=128)),
                ('accesskeyid', models.CharField(max_length=128)),
                ('secretkey', models.CharField(max_length=255)),
                ('repo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.Repository')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Screenshot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(default='en', max_length=32)),
                ('type', models.CharField(choices=[('phoneScreenshots', 'Phone'), ('sevenInchScreenshots', "7'' Tablet"), ('tenInchScreenshots', "10'' Tablet"), ('tvScreenshots', 'TV'), ('wearScreenshots', 'Wearable')], default='phoneScreenshots', max_length=32)),
                ('file', models.ImageField(max_length=1024, storage=repomaker.storage.RepoStorage(), upload_to=repomaker.storage.get_screenshot_file_path)),
                ('app', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.App')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SshStorage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('host', models.CharField(max_length=256, validators=[repomaker.models.storage.HostnameValidator()])),
                ('path', models.CharField(max_length=512, validators=[repomaker.models.storage.PathValidator()])),
                ('identity_file', models.FileField(blank=True, storage=repomaker.storage.PrivateStorage(), upload_to=repomaker.storage.get_identity_file_path)),
                ('public_key', models.TextField(blank=True, null=True)),
                ('url', models.URLField(max_length=2048)),
                ('disabled', models.BooleanField(default=True)),
                ('username', models.CharField(max_length=64, validators=[repomaker.models.storage.UsernameValidator()])),
                ('repo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.Repository')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='remoteapp',
            name='repo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.RemoteRepository'),
        ),
        migrations.AddField(
            model_name='remoteapkpointer',
            name='app',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.RemoteApp'),
        ),
        migrations.AddField(
            model_name='gitstorage',
            name='repo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.Repository'),
        ),
        migrations.AddField(
            model_name='app',
            name='category',
            field=models.ManyToManyField(blank=True, to='repomaker.Category'),
        ),
        migrations.AddField(
            model_name='app',
            name='repo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.Repository'),
        ),
        migrations.AddField(
            model_name='app',
            name='tracked_remote',
            field=models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='repomaker.RemoteApp'),
        ),
        migrations.AddField(
            model_name='apkpointer',
            name='app',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='repomaker.App'),
        ),
        migrations.AddField(
            model_name='apkpointer',
            name='repo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='repomaker.Repository'),
        ),
        migrations.AlterUniqueTogether(
            name='remoteapptranslation',
            unique_together=set([('language_code', 'master')]),
        ),
        migrations.AlterUniqueTogether(
            name='remoteapp',
            unique_together=set([('package_id', 'repo')]),
        ),
        migrations.AlterUniqueTogether(
            name='remoteapkpointer',
            unique_together=set([('apk', 'app')]),
        ),
        migrations.AlterUniqueTogether(
            name='category',
            unique_together=set([('user', 'name')]),
        ),
        migrations.AlterUniqueTogether(
            name='apptranslation',
            unique_together=set([('language_code', 'master')]),
        ),
        migrations.AlterUniqueTogether(
            name='app',
            unique_together=set([('package_id', 'repo')]),
        ),
        migrations.AlterUniqueTogether(
            name='apkpointer',
            unique_together=set([('apk', 'app')]),
        ),
    ]
